/*
 * Copyright (c) 2017, Red Hat Inc. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.gcbench.roots;

import org.openjdk.jmh.annotations.*;

import java.util.concurrent.TimeUnit;

@Warmup(iterations = 5, time = 1, timeUnit = TimeUnit.SECONDS)
@Measurement(iterations = 5, time = 1, timeUnit = TimeUnit.SECONDS)
@Fork(1)
@BenchmarkMode(Mode.AverageTime)
@OutputTimeUnit(TimeUnit.MILLISECONDS)
@Threads(Threads.MAX)
@State(Scope.Benchmark)
public class Classes {

    @Param({"1", "10", "1000", "10000", "100000"})
    int classes;

    @Param({"1", "10", "100", "1000"})
    int classloaders;

    Class<?>[] arr;
    ClassGenerator.ByteClassLoader[] cls;

    @Setup
    public void setup() throws Exception {
        arr = new Class[classes];
        cls = new ClassGenerator.ByteClassLoader[classloaders];
        int classesPerCl = classes / classloaders;
        for (int c = 0; c < classloaders; c++) {
            cls[c] = new ClassGenerator.ByteClassLoader();
            for (int v = 0; v < classesPerCl; v++) {
                arr[c*classesPerCl + v] = ClassGenerator.generate(cls[c]);
            }
        }
    }

    @Benchmark
    public Object test() {
        return new Object();
    }

}
